##############################################################################
# cmake configuration file for SIO
#
# Exported Targets
#
#   SIO::sio       : Base sio library
#   SIO::sio-dump  : sio-dump utility
#
# returns following variables:
#
#   SIO_FOUND      : set to TRUE if SIO found
#       if FIND_PACKAGE called with REQUIRED and COMPONENTS arguments
#       SIO_FOUND is only set to TRUE if ALL components are also found
#       if REQUIRED is NOT set components may or may not be available
#
#   SIO_VERSION    : package version
#   SIO_LIBRARIES  : list of SIO libraries (NOT including COMPONENTS)
#   SIO_INCLUDE_DIRS  : list of paths to be used with INCLUDE_DIRECTORIES
#
# @author Jan Engels, Desy
# @author Remi Ete, Desy
##############################################################################

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was SIOConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib64/cmake/SIO" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

SET( SIO_VERSION "0.2.0" )

# ---------- include dirs -----------------------------------------------------
SET_AND_CHECK(SIO_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include")
# # do not store find results in cache
MARK_AS_ADVANCED( SIO_INCLUDE_DIRS )

# If we are not building zlib ourselves (and statically link to it) make sure
# that whatever zlib we found, is also found by the dependencies
IF(NOT ON)
  INCLUDE(CMakeFindDependencyMacro)
  FIND_DEPENDENCY(ZLIB)
ENDIF()

# # ---------- libraries --------------------------------------------------------
IF(NOT TARGET SIO::sio)
  INCLUDE("${CMAKE_CURRENT_LIST_DIR}/SIOTargets.cmake")
ENDIF()

# ---------- final checking ---------------------------------------------------
INCLUDE( FindPackageHandleStandardArgs )
# set SIO_FOUND to TRUE if all listed variables are TRUE and not empty
# SIO_COMPONENT_VARIABLES will be set if FIND_PACKAGE is called with REQUIRED argument
# Get the location from the target and ensure that it is present with the call below
GET_PROPERTY(SIO_LIBRARY_TEST TARGET SIO::sio PROPERTY LOCATION)
SET(SIO_LIBRARIES SIO::sio)
MARK_AS_ADVANCED(SIO_LIBRARIES)

FIND_PACKAGE_HANDLE_STANDARD_ARGS( SIO DEFAULT_MSG SIO_INCLUDE_DIRS SIO_LIBRARIES SIO_LIBRARY_TEST)
